@@ -11,7 +11,7 @@ class SecurityTxtTests(TestCase):
         self.assertEqual(response.status_code, HTTPStatus.OK)
         self.assertEqual(response["content-type"], "text/plain")
         content = response.content.decode()
-        self.assertTrue(content.startswith("Contact: " + settings.WELLKNOWN_SECURITY_CONTACT))
+        self.assertTrue(content.startswith("Contact: "))
 
     def test_post_disallowed(self):
         response = self.client.post("/.well-known/security.txt")
